/************************************************************************************************************
 **   GEMM - a generic mobility model  for generating realistic mobility scenarios                                          
 **   Copyright (C) 2003, 2004 Suprio Ray
 **   Copyright (C) 2003, 2004 University of British Columbia, Canada                             
 **                                                                           
 ** This program is free software; you can redistribute it and/or modify      
 ** it under the terms of the GNU General Public License as published by      
 ** the Free Software Foundation; either version 2 of the License, or         
 ** (at your option) any later version.                                       
 **                                                                           
 ** This program is distributed in the hope that it will be useful,           
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of           
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            
 ** GNU General Public License for more details.                              
 **                                                                           
 ** You should have received a copy of the GNU General Public License        
 ** along with this program; if not, write to the Free Software             
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 *************************************************************************************************************/

/**  GemmMain.java
 *  @description 
 *  @author  Suprio Ray
 *  @date  Sept. 03, 2003
 *  @version GEMM 1.0
 */
package ca.ubc.cs. gemm.run;

import ca.ubc.cs. gemm.*;


public class GemmMain  {

	
	private final String  GEMM_MODEL = "ca.ubc.cs.gemm.GemmModel";
	
	public static void displayHelp() {
		System.out.println("Help:");
		System.out.println("  -h 	Print this help");
		System.out.println("");
		System.out.println("Scenario generation:");
		System.out.println("  -f <scenario name>  -x <x-dimension>  -y <y-dimension>  -A <attraction point params> -V <activity params> -R <role params>  -G <group mobility params> ");
	
	}


	public static void main(String[] args) throws Throwable {
		    
				System.out.println("GEMM vestion 1.0");
				new GemmMain(args);
		}
	
		private GemmMain(String[] _args) throws Throwable {
		

		   if (_args.length == 0) {
			displayHelp();
		   } 
		   else {	
				if (_args[0].equals("-h"))
					displayHelp();
				else {
						System.out.println("Starting GEMM...");		
						Class modelClass= Class.forName(GEMM_MODEL);
				
						if (modelClass  != null) {
						try {
							if (!_args[0].equals("-f")) {
								System.out.println("please specify scenario filename using -f option");
								displayHelp();
								System.exit(0);
							}
							else {	
							   String scenarioFile = _args[1];
							   String[] params = new String[_args.length - 2];
								System.arraycopy(_args, 2,params, 0,params.length);
							    Class[] constType = {String[].class};
							    Object[] constParams = {params};
							    ((GemmScenario)modelClass.getConstructor(constType).newInstance(constParams)).write(scenarioFile);
						
					    } 
					}  catch (Exception e) {
							System.out.println("Error in GemmMain.java: "+ e.getMessage() + "\n" + e.getStackTrace());
							e.printStackTrace();
					     }
				}
				else {
					System.err.println("Can't find model class");	
				}
			}
		}

	} // end constructor
} // end GemmMain
