/************************************************************************************************************
 **   GEMM - a generic mobility model  for generating realistic mobility scenarios                                          
 **   Copyright (C) 2003, 2004 Suprio Ray
 **   Copyright (C) 2003, 2004 University of British Columbia, Canada                             
 **                                                                           
 ** This program is free software; you can redistribute it and/or modify      
 ** it under the terms of the GNU General Public License as published by      
 ** the Free Software Foundation; either version 2 of the License, or         
 ** (at your option) any later version.                                       
 **                                                                           
 ** This program is distributed in the hope that it will be useful,           
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of           
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            
 ** GNU General Public License for more details.                              
 **                                                                           
 ** You should have received a copy of the GNU General Public License        
 ** along with this program; if not, write to the Free Software             
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 *************************************************************************************************************/


/** Rcbr.java
 *  @description Generates text file with random CBR  
 *  @author  Suprio Ray
 *  @date   Oct 11, 2003
 *  @version GEMM 1.0
 */

package ca.ubc.cs.gemm.util;


import java.io.*;
import java.util.*;


class Rcbr {

    final static String fileName = "app.conf";

    public static void main(String args[]) {
	
	int numNodes=0, pktSize=0, numSrc=0;
	float simPeriod=0, iPktInterval=0, rcbrInterval=0;
      

	System.out.println("num args " + args.length );
       
	if (args.length != 6) {
	    System.out.println("Error in syntax");
	    System.out.println("rcbr syntax: <num nodes> <num sources> <total simulation period (S)> <inter-packet interval (S)> <RCBR interval> <item size>");
        }
	else { 
	    
	    numNodes = Integer.parseInt(args[0]);
	    numSrc = Integer.parseInt(args[1]);
	    pktSize = Integer.parseInt(args[5]);
	    
	    simPeriod = Float.parseFloat(args[2]);
	    iPktInterval = Float.parseFloat(args[3]);
	    rcbrInterval =  Float.parseFloat(args[4]);

	    float time =0;
	    int numItems = (int) (1/iPktInterval *  rcbrInterval);

	    Random rnd = new Random( System.currentTimeMillis());
	    
	    
	    Integer src, dst;
	    try {
			PrintWriter pr = new PrintWriter(new BufferedWriter ( new FileWriter(fileName)));
			
			for (; time < simPeriod; time = time + rcbrInterval) {
				HashMap hm = new HashMap();
		    	for (int i=0; i< numSrc; i++) {
					do {
			    		src = new Integer(rnd.nextInt(numNodes));
					} while ( hm.containsKey(src));
					hm.put(src, new Integer(i));
			   
					do {
			    		dst = new Integer(rnd.nextInt(numNodes));
					} while ( hm.containsKey(dst));
					hm.put(dst, new Integer(i));
		    
					pr.println("CBR " + src.intValue() + " " + dst.intValue() + " " + numItems + " " + pktSize + " " +  
				   	iPktInterval + "S " + time + "S " + (time + rcbrInterval)  + "S ");
		    	} // end for
		    	pr.println();
			}// end for
			
			pr.close();
	    } catch (Exception e) {e.printStackTrace();}	
	}// end if
 }// end main

}
